package de.unibi.airobots.bonsai.core.configuration;

import java.util.Map;

/**
 * Configuration of one factory.
 * 
 * @author jwienke
 */
public class ConfiguredCoreObjectFactory {

    private String factoryClassName;
    private Map<String, String> factroyOptions;

    /**
     * Returns the name of the factory class.
     * 
     * @return factory class name
     */
    public String getFactoryClassName() {
        return factoryClassName;
    }

    /**
     * Sets the name of the factory class.
     * 
     * @param factoryClassName
     *            class name
     */
    public void setFactoryClassName(String factoryClassName) {
        this.factoryClassName = factoryClassName;
    }

    /**
     * Returns a map of key-value style options passed to this factory.
     * 
     * @return options
     */
    public Map<String, String> getFactroyOptions() {
        return factroyOptions;
    }

    /**
     * Sets the map of key-value style options passed to a factory.
     * 
     * @param factroyOptions
     *            new options
     */
    public void setFactroyOptions(Map<String, String> factroyOptions) {
        this.factroyOptions = factroyOptions;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean equals(Object obj) {
        if (!(obj instanceof ConfiguredCoreObjectFactory)) {
            return false;
        }
        ConfiguredCoreObjectFactory other = (ConfiguredCoreObjectFactory) obj;
        return other.factoryClassName.equals(factoryClassName)
                && other.factroyOptions.equals(factroyOptions);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode() {
        // CHECKSTYLE:OFF
        return factoryClassName.hashCode() * 3 + factroyOptions.hashCode() * 7;
        // CHECKSTYLE:ON
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return "[" + getClass().getSimpleName() + ": factoryClassName = "
                + factoryClassName + ", factoryOptions: " + factroyOptions
                + "]";
    }

}
