package de.unibi.airobots.bonsai.core.configuration;

/**
 * One sensor configured by the user in the configuration file.
 * 
 * @author jwienke
 */
public class ConfiguredSensor extends ConfiguredCoreObject {

    private String dataTypeClassName;
    private String sensorClassName;

    /**
     * Returns the class name of the data type the sensor produces as specified
     * in the config.
     * 
     * @return data type class name
     */
    public String getDataTypeClassName() {
        return dataTypeClassName;
    }

    /**
     * Sets the class name of the data type the sensor produces as specified in
     * the config.
     * 
     * @param dataTypeClassName
     *            data type class name
     */
    public void setDataType(String dataTypeClassName) {
        this.dataTypeClassName = dataTypeClassName;
    }

    /**
     * Returns the name of the implementing class for the sensor as specified in
     * the config.
     * 
     * @return sensor class name
     */
    public String getSensorClassName() {
        return sensorClassName;
    }

    /**
     * Sets the name of the implementing class for the sensor as specified in
     * the config.
     * 
     * @param sensorClassName
     *            sensor class name
     */
    public void setSensorClassName(String sensorClassName) {
        this.sensorClassName = sensorClassName;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return "[" + getClass().getSimpleName() + ": key = " + getKey()
                + ", dataTypeClassName = " + dataTypeClassName
                + ", factoryClassName = " + getFactoryClassName()
                + ", sensorOption = " + getOptions() + "]";
    }

}
