package de.unibi.airobots.bonsai.sensors.data;

import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;

import de.unibi.airobots.btl.data.PersonData;

/**
 * Domain class holding Person objects.
 * 
 * @author lschilli
 */
public class PersonList implements Iterable<PersonData> {

    private HashMap<Integer, PersonData> personmap =
            new LinkedHashMap<Integer, PersonData>();

    /**
     * Adds a person to this list.
     * 
     * @param p
     *            new person to add
     */
    public void addPerson(PersonData p) {
        personmap.put(p.getId(), p);
    }

    /**
     * Returns the person with the given id in this list or <code>null</code> if
     * not contained.
     * 
     * @param id
     *            id to search for
     * @return person or <code>null</code> if not found
     */
    public PersonData getPersonById(int id) {
        return personmap.get(id);
    }

    @Override
    public Iterator<PersonData> iterator() {
        return personmap.values().iterator();
    }

    /**
     * Returns the number of contained persons.
     * 
     * @return number >= 0
     */
    public int size() {
        return personmap.size();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return personmap.values().toString();
    }

}
