package de.unibi.airobots.bonsai.util;

import java.nio.ByteBuffer;

/**
 * For conversion of (binary) data from one format to another.
 * 
 * @author lziegler
 */
public class DataConverter {

    /**
     * Converts an array of float into a byte array.
     * 
     * @param floatData
     *            The floats to convert.
     * @return An array of byte.
     */
    public static byte[] toByteArray(float[] floatData) {

        ByteBuffer bb = ByteBuffer.allocate(4 * floatData.length);
        for (int i = 0; i < floatData.length; i++) {
            bb.putFloat(floatData[i]);
        }
        byte[] byteArray = bb.array();
        return byteArray;
    }

    /**
     * Converts a single float into a byte array.
     * 
     * @param floatData
     *            The float to convert.
     * @return An array of byte.
     */
    public static byte[] toByteArray(float floatData) {

        ByteBuffer bb = ByteBuffer.allocate(4);
        bb.putFloat(floatData);
        byte[] byteArray = bb.array();
        return byteArray;
    }

    /**
     * Converts an array of byte into a float array.
     * 
     * @param byteData
     *            The bytes to convert.
     * @return An array of float.
     */
    public static float[] toFloatArray(byte[] byteData) {

        ByteBuffer bb = ByteBuffer.wrap(byteData);
        float[] floatData = new float[byteData.length / 4];
        int i = 0;
        while (bb.hasRemaining()) {
            float value = bb.getFloat();
            floatData[i++] = value;
        }
        return floatData;
    }
}
