package de.unibi.airobots.bonsai.util.helper;

import java.io.IOException;

import org.apache.log4j.Logger;

import de.unibi.airobots.btl.data.GlobalPlannerStateChange;
import de.unibi.airobots.btl.data.NavigationGoalData;
import de.unibi.airobots.btl.data.SpeedData;
import de.unibi.airobots.bonsai.util.helper.GoalReachedWaiter.ReachStatus;
import de.unibi.airobots.bonsai.actuators.NavigationActuator;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.util.CoordinateSystemConverter;
import de.unibi.airobots.btl.data.PositionData;
import de.unibi.airobots.btl.data.NavigationGoalData.GoalType;

public class Movements {

	private static final long TIMEOUT = 150000;

	public static Logger logger = Logger.getLogger(Movements.class);

	public static ReachStatus turnAround(Sensor<PositionData> positionSensor,
			Sensor<SpeedData> speedSensor,
			Sensor<GlobalPlannerStateChange> gplanChangeSensor,
			NavigationActuator navigationActuator) throws IOException,
			InterruptedException {

		return turnAroundAndMoveBack(0.0, positionSensor, speedSensor,
				gplanChangeSensor, navigationActuator);

	}

	public static ReachStatus turnAroundAndMoveBack(double meters,
			Sensor<PositionData> positionSensor, Sensor<SpeedData> speedSensor,
			Sensor<GlobalPlannerStateChange> gplanChangeSensor,
			NavigationActuator navigationActuator) throws IOException,
			InterruptedException {

		logger.info("Starting to turn around with moving back " + meters
				+ " meters.");

		NavigationGoalData target = CoordinateSystemConverter
				.polar2NavigationGoalData(positionSensor.readLast(), Math.PI,
						meters);
		target.setYawTolerance(Math.PI / 8.0);
		
		navigationActuator.setGoal(target);

		GoalReachedWaiter waiter = new GoalReachedWaiter(positionSensor,
				speedSensor, gplanChangeSensor, navigationActuator);

		ReachStatus reached = waiter.waitForReachingGoal(target, TIMEOUT);

		logger.info("Turning around finished: reached = " + reached);

		return reached;

	}

	public static boolean driveToPosition(NavigationActuator navigationActuator,
			Sensor<PositionData> positionSensor, Sensor<SpeedData> speedSensor,
			Sensor<GlobalPlannerStateChange> gplanChangeSensor,
			NavigationGoalData target)
			throws IOException {
	    
	        return driveToPosition(navigationActuator, positionSensor, speedSensor, gplanChangeSensor, target, GoalType.GLOBAL);

	}
	
	public static boolean driveToPosition(NavigationActuator navigationActuator,
            Sensor<PositionData> positionSensor, Sensor<SpeedData> speedSensor,
            Sensor<GlobalPlannerStateChange> gplanChangeSensor,
            NavigationGoalData target, GoalType type)
            throws IOException {
	    
	    logger.debug("start drive to positions");
	    target.setType(type);   
	    
        navigationActuator.setGoal(target);
        
        logger.debug("new goalReachedWaiter");
        GoalReachedWaiter waiter = new GoalReachedWaiter(positionSensor,
                speedSensor, gplanChangeSensor, navigationActuator);

        logger.debug("wait for reaching goal");
        ReachStatus reached = waiter.waitForReachingGoal(target, TIMEOUT);

        logger.debug("Driving with status:" + reached);

        if (reached.equals(ReachStatus.NOT_REACHED_BLOCKED)) {
            
            target.setType(GoalType.LOCAL);
            
            reached = new GoalReachedWaiter(positionSensor, speedSensor,
                    gplanChangeSensor, navigationActuator).waitForReachingGoal(target,
                    TIMEOUT);
        }
        
        if (reached.equals(ReachStatus.REACHED)) {
            return true;
        } else {
            return false;
        }
	    
	}
}
