package de.unibi.airobots.bonsai.xcf.configuration;

import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.airobots.bonsai.xcf.sensors.XcfBinarySlamSensor;
import de.unibi.airobots.btl.data.BinarySlamMap;

/**
 * Configuration for {@link XcfBinarySlamSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@link ConfiguredXcfSensor#OPTION_PUBLISHER_NAME} (required): name of the
 * publisher to register on</li>
 * </ul>
 * 
 * @author jwienke
 */
public class ConfiguredXcfBinarySlamSensor extends
        ConfiguredXcfBtlPublisherSensor<BinarySlamMap> {

    /**
     * {@inheritDoc}
     */
    @Override
    public Sensor<BinarySlamMap> createInstance() {
        return new XcfBinarySlamSensor(getPublisherName());
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(SensorToConfigure sensor) {
        return sensor.getSensorClass().equals(XcfBinarySlamSensor.class);
    }

}
