/**
 * Contains the XCF specific implementations of sensors, actuators and a
 * factory.
 * 
 * <p>
 * Central class is {@link de.unibi.airobots.bonsai.xcf.XcfFactory} which is an
 * implementation of {@link de.unibi.airobots.bonsai.core.CoreObjectFactory}.
 * This factory manages the creation of XCF-based sensors and actuators. The
 * general idea is that all sensors and actuators can reconnect to XCF
 * infrastructure units like servers or publishers. This task will not be
 * performed by every sensor or actuator to avoid cluttering the sensor or
 * actuator implementation code with connection housekeeping. Instead, instances
 * of {@link de.unibi.airobots.bonsai.xcf.ReconnectableManager} perform these
 * tasks. The <code>XcfFactory</code> contains on instance of such a manager for
 * each XCF infrastructure Unit (except Active Memory because of a bug in the
 * client api) delegating the connection task to these managers. A sensor or
 * actuator that wants to be reconnected to such an infrastructure unit, it must
 * implement one of the <code>XxxReconnectable</code> interfaces.
 * </p>
 * 
 * <p>
 * The basic idea behind the design of the Reconnectables is to use the original
 * XCF class interface for {@link net.sf.xcf.RemoteServer} or
 * {@link net.sf.xcf.Subscriber} whenever possible so that the sensors can be
 * easily used without reconnection mechanisms, too.
 * </p>
 * 
 * <p>
 * The basic principle to register new XCF-specific sensors or actuators is to
 * provide two classes:
 * <ul>
 * <li>The actual sensor implementation</li>
 * <li>A configuration class for the sensor</li>
 * </ul>
 * The task of the configuration object is to validate and store the
 * configuration for a sensor that the user provided in the configuration file
 * and to create new instance of the sensor/actuator based on this
 * configuration. {@link de.unibi.airobots.bonsai.xcf.XcfFactory} describes how
 * these configuration objects are discovered.
 * </p>
 */
package de.unibi.airobots.bonsai.xcf;

